<?php
/**
* @package		EasySocial
* @copyright	Copyright (C) 2010 - 2015 Stack Ideas Sdn Bhd. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* EasySocial is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

class plgContentEsMtree extends JPlugin
{
	protected $autoloadLanguage = true;

	/**
	 * Load EasySocial's engine
	 *
	 * @since	2.0
	 * @access	public
	 */
	public function exists()
	{
		$file = JPATH_ADMINISTRATOR . '/components/com_easysocial/includes/easysocial.php';

		if (!JFile::exists($file)) {
			return false;
		}

		require_once($file);

		return true;
	}

	/**
	 * Triggers when a mosets listing is published
	 *
	 * @since	2.0
	 * @access	public
	 */
	public function onContentAfterSave($extension, $item, $isNew)
	{
		if ($extension != 'com_mtree.listing' || !$isNew) {
			return;
		}

		// Generate a new stream
		$tmpl = ES::stream()->getTemplate();

		// Get the item data
		$db = JFactory::getDbo();
		$link = new mtLinks($db);
		$link->load($item->link_id);

		$tmpl->setActor($link->user_id, SOCIAL_TYPE_USER);
		$tmpl->setContext($link->link_id, 'mtree');
		$tmpl->setVerb('create');
		$tmpl->setAccess('core.view');

		ES::stream()->add($tmpl);
	}

	/**
	 * Renders the author's information
	 *
	 * @since	1.3
	 * @access	public
	 */
	public function onContentAfterTitle($extension, &$item, &$params)
	{
		if ($extension != 'com_mtree.listing') {
			return;
		}

		// Check if ES is installed
		if (!$this->exists()) {
			return;
		}

		$file = __DIR__ . '/tmpl/title.php';

		// Get the author
		$author = FD::user($item->user_id);


		ob_start();
		require($file);
		$contents = ob_get_contents();
		ob_end_clean();

		return $contents;
	}

	/**
	 * Renders the author box after the content
	 *
	 * @since	1.3
	 * @access	public
	 */
	public function onContentAfterDisplay($extension, &$item, &$params)
	{
		if ($extension != 'com_mtree.listing') {
			return;
		}
	
		if (!$this->exists()) {
			return;
		}

		$uniqueKey = $this->params->get('field_code_about', '');

		if (!$uniqueKey) {
			return;
		}


		$file = __DIR__ . '/tmpl/author.php';

		// Get the author 
		$author = ES::user($item->user_id);

		// Get the custom field value
		$about = $author->getFieldValue($uniqueKey);

		if (!$about) {
			$about = JText::_('PLG_CONTENT_ESMTREE_ABOUT_NOT_AVAILABLE');
		}

		ob_start();
		require($file);
		$contents = ob_get_contents();
		ob_end_clean();

		return $contents;
	}

	/**
	 * Retrieves the plugin params
	 *
	 * @since	1.0
	 * @access	public
	 */
	public function getPluginParams()
	{
		static $params = false;

		if (!$params) {

			$plugin = JPluginHelper::getPlugin('content', 'esmtree');
			$params = FD::registry($plugin->params);
		}

		return $params;
	}
}
